import { PromiseState } from 'mobx-utils';
import { InlineValue } from './inline-value';
/**
 * List of options supported by components which present a list of options from
 * which to select.
 */
export declare type Options<T = any> = Array<Option<T>>;
/**
 * Type of an option supported by components which present a list of options
 * from which to select.
 */
export interface Option<T = any> {
    /**
     * Value of the option.
     */
    value: T;
    /**
     * Human-readable string to represent the option.
     */
    label?: string;
    /**
     * Code of the option.
     */
    code?: string;
    /**
     * Help message associated with the option.
     */
    helpMessage?: string;
    /**
     * Whether the option should show up as disabled.
     */
    isDisabled?: boolean;
}
/**
 * Class which represents a component whose value may be restricted by a set of
 * options.
 */
export declare abstract class SelectionValue extends InlineValue {
    /**
     * Text to be shown when there are no options available.
     */
    readonly noOptionsText: string;
    /**
     * Selectable options.
     */
    readonly options: Options;
    private readonly _options;
    /**
     * Promise-status of the options.
     */
    readonly optionsStatus: PromiseState;
}
