import { Injector, OnInit } from '@angular/core';
import { IObservableArray } from 'mobx';
/**
 * Class that represents a container of columns: super class of both the table
 * header and of the column (which may have sub-columns as children).
 */
export declare abstract class TableColumnContainer implements OnInit {
    protected _injector: Injector;
    protected _parentTableColumnContainer: TableColumnContainer | null;
    protected _childrenColumns: IObservableArray<TableColumnContainer>;
    constructor(_injector: Injector, _parentTableColumnContainer?: TableColumnContainer | null);
    ngOnInit(): void;
    /**
     * List of column controllers that are direct children of this table column
     * container.
     * @returns List of column children.
     */
    readonly childrenColumns: TableColumnContainer[];
    /**
     * Method used by child columns to register themselves in this container.
     * @param column Column to register in this container.
     */
    _addColumn(column: TableColumnContainer): void;
    /**
     * Height of a column container (height of the tree represented by the column
     * container as root, and its columns as children).
     * @returns Height of the column container.
     */
    protected readonly _height: number;
    /**
     * Width of a column container (width of the tree represented by the column
     * container as root, and its columns as children).
     * @returns Width of the column container.
     */
    protected readonly _width: number;
}
