import { PathBased } from '@lightweightform/core';
/**
 * Abstract class that all components which "encapsulate" a storage value should
 * inherit.
 */
export declare abstract class Value extends PathBased {
    /**
     * Whether the component should render in "read-only" mode (this has no effect
     * if this component is within an already "read-only" component).
     */
    _isReadOnly: boolean;
    /**
     * Add an `lf-value` class to all value components.
     */
    _classLfValue: boolean;
    /**
     * Label associated with this value.
     */
    readonly label: string | undefined;
    /**
     * Code associated with this value.
     */
    readonly code: string | undefined;
    /**
     * Help message associated with this value.
     */
    readonly helpMessage: string | undefined;
    /**
     * Legend associated with this value.
     */
    readonly legend: string | undefined;
    /**
     * Message used to ask the user to retry validating the value.
     */
    readonly retryValidateText: string;
    /**
     * Whether the component should render in "read-only" mode. Inherits the
     * "read-only" state of parent components (meaning that it's not possible to
     * have an "editable" component within a "read-only" one). Furthermore, if the
     * component's value is computed, the component will always be in "read-only"
     * mode.
     */
    readonly isReadOnly: boolean;
}
