import { ElementRef } from '@angular/core';
/**
 * Available styles for a `lfButton`.
 */
export declare type ButtonStyle = 'primary' | 'secondary' | 'success' | 'danger' | 'warning' | 'info' | 'light' | 'dark' | 'link' | 'outline-primary' | 'outline-secondary' | 'outline-success' | 'outline-danger' | 'outline-warning' | 'outline-info' | 'outline-light' | 'outline-dark';
/**
 * Available sizes for a `lfButton`.
 */
export declare type ButtonSize = 'sm' | 'lg';
/**
 * Bootstrap button component.
 */
export declare class ButtonComponent {
    /**
     * Button style. See available styles at [Bootstrap documentation](
     * https://getbootstrap.com/docs/4.0/components/buttons/#examples).
     */
    style?: ButtonStyle;
    /**
     * Button size. See available sizes at [Bootstrap documentation](
     * https://getbootstrap.com/docs/4.0/components/buttons/#sizes).
     */
    size?: ButtonSize;
    /**
     * HTML button type.
     */
    type: 'button' | 'submit' | 'reset';
    /**
     * Match the width of parent if `true`.
     */
    block: boolean;
    /**
     * Display a dropdown icon (this is automatic if `dropdownToggleSplit` is
     * set).
     */
    dropdownToggle: boolean;
    /**
     * Reduces the padding of the button so it can be used as the dropdown part of
     * a split dropdown.
     */
    dropdownToggleSplit: boolean;
    /**
     * Set the button as disabled.
     */
    isDisabled: boolean;
    /**
     * Set the button as active.
     */
    isActive: boolean;
    /**
     * Always add the class `btn` to LF buttons.
     */
    _hostClassBtn: boolean;
    /**
     * Tag of the element (`'button'` or `'a'`).
     */
    protected _tagName: string;
    constructor(_host: ElementRef);
    readonly _role: "button" | undefined;
    readonly _hostClassBtnPrimary: boolean;
    readonly _hostClassBtnSecondary: boolean;
    readonly _hostClassBtnSuccess: boolean;
    readonly _hostClassBtnDanger: boolean;
    readonly _hostClassBtnWarning: boolean;
    readonly _hostClassBtnInfo: boolean;
    readonly _hostClassBtnLight: boolean;
    readonly _hostClassBtnDark: boolean;
    readonly _hostClassBtnLink: boolean;
    readonly _hostClassBtnOutlinePrimary: boolean;
    readonly _hostClassBtnOutlineSecondary: boolean;
    readonly _hostClassBtnOutlineSuccess: boolean;
    readonly _hostClassBtnOutlineDanger: boolean;
    readonly _hostClassBtnOutlineWarning: boolean;
    readonly _hostClassBtnOutlineInfo: boolean;
    readonly _hostClassBtnOutlineLight: boolean;
    readonly _hostClassBtnOutlineDark: boolean;
    readonly _hostClassBtnSm: boolean;
    readonly _hostClassBtnLg: boolean;
    readonly _hostClassDropdownToggle: boolean;
    readonly _hostType: "button" | "submit" | "reset" | undefined;
    readonly _hostDisabled: "" | undefined;
    readonly _hostAriaDisabled: "true" | undefined;
    readonly _hostAriaPressed: "true" | undefined;
}
