import { Value } from '../../abstract/value';
import { ActionsMenuAction } from '../actions-menu/actions-menu.component';
import { ModalComponent } from '../modal/modal.component';
/**
 * HTML string of the form component.
 */
export declare const formComponentHtml: string;
/**
 * LF form component.
 */
export declare class FormComponent extends Value {
    /**
     * Modal used to show the form's help message.
     */
    _helpModal: ModalComponent;
    /**
     * Modal used to ask for confirmation when attempting to remove the form.
     */
    _removeModal: ModalComponent;
    ngOnInit(): void;
    /**
     * Text used for the "help" action.
     */
    readonly helpActionText: string;
    /**
     * Text used for the "remove" action.
     */
    readonly removeActionText: string;
    /**
     * Message displayed to the user to confirm removal of the form.
     */
    readonly ensureRemoveText: string;
    /**
     * Text for the "cancel" button in the removal modal.
     */
    readonly cancelRemoveButtonText: string;
    /**
     * Text for the "confirm" button in the removal modal.
     */
    readonly confirmRemoveButtonText: string;
    /**
     * Whether this form can be removed (if it is `nullable` or its parent is a
     * list or map).
     */
    readonly isRemovable: boolean;
    /**
     * Removes this form by either setting it to `null` (when it is `nullable` or
     * removing it from its parent list or map).
     */
    remove(): void;
    /**
     * Form-related actions shown on the top of the form.
     */
    readonly _formActions: ActionsMenuAction[];
    _cancelRemove(): void;
    _confirmRemove(): Promise<void>;
    protected validatePath(): void;
    private showHelpModal;
    private showRemoveModal;
}
