import { AfterViewInit, ElementRef, EventEmitter } from '@angular/core';
import { Toggleable } from '../../abstract/toggleable';
/**
 * HTML string of the modal component.
 */
export declare const modalComponentHtml: string;
/**
 * Available modal sizes.
 */
export declare type BsModalSize = 'sm' | 'lg';
export declare const I18N_MODAL_CLOSE_TOOLTIP_KEY = "LF_MODAL_CLOSE_TOOLTIP";
/**
 * LF modal component.
 */
export declare class ModalComponent extends Toggleable implements AfterViewInit {
    /**
     * Size of the modal component. See available sizes at
     * [Bootstrap documentation](
     * https://getbootstrap.com/docs/4.0/components/modal/#optional-sizes).
     */
    size: BsModalSize;
    /**
     * Whether to center the modal vertically on screen.
     */
    isCentered: boolean;
    /**
     * Whether to animate the modal component.
     */
    animate: boolean;
    /**
     * Whether to enable closing the modal by pressing the `Esc` key.
     */
    closeWithEsc: boolean;
    /**
     * Whether to show a dark background underneath the the modal when it appears.
     */
    showBackdrop: boolean;
    /**
     * Whether to disable closing the modal by clicking on the backdrop.
     */
    ignoreBackdropClick: boolean;
    /**
     * If the modal contains `<input>`, `<select>`, or `<textarea>` elements
     * within, focus the first found element after the modal opens.
     */
    autoFocus: boolean;
    /**
     * Event emitter which emits an event whenever the modal finishes showing.
     */
    onShown: EventEmitter<void>;
    /**
     * Event emitter which emits an event whenever the modal finishes hiding.
     */
    onHidden: EventEmitter<void>;
    protected _modal: ElementRef;
    protected _$modal: any;
    protected _animating: boolean;
    protected _disposeOnOptionsChange: () => void;
    protected _onShowUnsubscribe: () => void;
    protected _onHideUnsubscribe: () => void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    /**
     * Tooltip text used by the modal's close button.
     */
    readonly closeModalTooltipText: any;
    /**
     * Method to call on long modals when their content change, which forces their
     * height to also change.
     */
    refresh(): void;
    /**
     * @override
     */
    hide(): Promise<void>;
    /**
     * @override
     */
    toggle(): Promise<void>;
    protected _createModal(): void;
    protected _destroyModal(): Promise<void>;
}
