import { LfMatchingRoute, PathBased } from '@lightweightform/core';
import { Identifier } from '@lightweightform/storage';
/**
 * HTML string of the tree-entry component.
 */
export declare const treeEntryComponentHtml: string;
/**
 * Entry for an item of the tree-nav.
 */
export declare class TreeEntryComponent extends PathBased {
    /**
     * Whether this tree-entry is to be displayed as the root one (in which case
     * its label isn't shown anywhere and its children are displayed one after the
     * other). The entry can be displayed as root only when its schema is complex.
     * A button is displayed at the end of the list when there are optional values
     * to be added or to add a new element in case the schema is a list.
     */
    displayAsRoot: boolean;
    /**
     * Internal input used to make a tree only show entries that render in the
     * same outlet (values that should render inside other components shouldn't be
     * part of the same tree).
     */
    _componentLevel: number;
    private lfRouter;
    private disposeOnDisplayAsRootChanges;
    ngOnInit(): void;
    ngOnDestroy(): void;
    /**
     * Label associated with this value.
     */
    readonly label: string | undefined;
    /**
     * Message used to ask the user to retry validating the value.
     */
    readonly retryValidateText: string;
    readonly addOptionalValueButtonText: string;
    readonly addValueToListButtonText: string;
    readonly matchingRoutes: LfMatchingRoute[];
    readonly navigateableRoute: LfMatchingRoute | null;
    readonly url: string | null;
    readonly isActive: boolean;
    readonly isList: boolean;
    readonly childrenIds: Identifier[];
    readonly nonNullChildrenIds: Identifier[];
    readonly nullChildrenIds: Identifier[];
    childLabel(id: Identifier): string;
    addToList(): void;
    initializeChild(id: string): void;
    /**
     * @override
     */
    protected validatePath(): void;
    /**
     * The "component" level of the provided matching route (basically the number
     * of outlets used by the route).
     * @param matchingRoute Matching of a route with a provided path.
     * @returns Component level for the matching route.
     */
    private matchingRouteComponentLevel;
}
