import { OnInit } from '@angular/core';
import { TableColumnContainer } from '../../abstract/table-column-container';
/**
 * Directive representing a table column (which may have sub-columns). Leaf
 * columns (columns with no sub-columns) may specify `minWidth` and `fixed` to
 * impose sizing restrictions on their respective table columns.
 */
export declare class TableColumnDirective extends TableColumnContainer implements OnInit {
    /**
     * Identifier of this column (used, for example, to set a label on the
     * respective table-header cell).
     */
    id: string;
    /**
     * Minimum width of a column (in pixels); this binding is only relevant when
     * applied to leaf columns. Note that the actual width of a column will be
     * relative the minimum width of all other columns; as an example a column
     * with a `minWidth` of `200` should always be twice as large as a column with
     * a `minWidth` of `100`.
     */
    minWidth?: number;
    /**
     * `fixed` columns have their width set to `minWidth` and their width won't
     * ever vary.
     */
    fixed: boolean;
    /**
     * `rowSpan` that should be set on the header table cell that represents this
     * column.
     * @returns`rowSpan` of the cell representing this column.
     */
    readonly rowSpan: number;
    /**
     * `colSpan` that should be set on the header table cell that represents this
     * column.
     * @returns `colSpan` of the cell representing this column.
     */
    readonly colSpan: number;
}
