import { DateSchema, KnownKeys, ParentContextFunction, Schema, TupleSchema } from '@lightweightform/storage';
/**
 * Date-range schema.
 */
export interface DateRangeSchema extends TupleSchema<[Date, Date], [DateSchema, DateSchema]> {
    /**
     * Minimum date that the date-range represented by this schema is allowed to
     * have.
     */
    minDate?: Date | ParentContextFunction<Date>;
    /**
     * Maximum date that the date-range represented by this schema is allowed to
     * have.
     */
    maxDate?: Date | ParentContextFunction<Date>;
}
/**
 * Options used to create a new date-range schema.
 */
export declare type DateRangeSchemaOptions = Pick<DateRangeSchema, Exclude<KnownKeys<DateRangeSchema>, 'type' | 'elementsSchemas'>> & {
    [extraProperties: string]: any;
};
/**
 * Creates a new date-range schema object.
 * @param options Options used to create the schema.
 * @returns Date-range schema.
 */
export declare function dateRangeSchema(options?: DateRangeSchemaOptions): DateRangeSchema;
/**
 * Returns whether a given schema is a date-range schema.
 * @param schema Schema to check.
 * @returns `true` when the provided schema is a date-range schema.
 */
export declare function isDateRangeSchema(schema: Schema): schema is DateRangeSchema;
